@@ -1,4 +1,4 @@
-__version__ = '0.0.57'
+__version__ = '0.0.58'
 
 PID_FILE = '/tmp/yedb-server.pid'
 
@@ -133,8 +133,8 @@ async def handle_jrpc(payload, remote_name):
             if isinstance(res, GeneratorType):
                 res = list(res)
             elif method == 'explain':
-                i = res['info']
-                del res['info']
+                i = res['metadata']
+                del res['metadata']
                 res['mtime'] = i.st_mtime
                 res['size'] = i.st_size
                 res['sha256'] = res['sha256'].hex()
